/*------------------------------------------------------------------------------
 * MDK Middleware - Component ::USB:Device
 * Copyright (c) 2004-2015 ARM Germany GmbH. All rights reserved.
 *------------------------------------------------------------------------------
 * Name:    HID.c
 * Purpose: USB Device Human Interface Device example program
 *----------------------------------------------------------------------------*/

#include "cmsis_os.h"
#include "rl_usb.h"
#include "Board_GLCD.h"
#include "GLCD_Config.h"
#include "Board_Joystick.h"
#include "Board_LED.h"

extern GLCD_FONT GLCD_Font_6x8;
extern GLCD_FONT GLCD_Font_16x24;

int main (void) {
  uint8_t joy;
  uint8_t buf;

  LED_Initialize          ();
  Joystick_Initialize     ();

  GLCD_Initialize         ();
  GLCD_SetBackgroundColor (GLCD_COLOR_BLUE);
  GLCD_SetForegroundColor (GLCD_COLOR_WHITE);
  GLCD_ClearScreen        ();
  GLCD_SetFont            (&GLCD_Font_16x24);
  GLCD_DrawString         (0, 0*24, "    USB Device      ");
  GLCD_DrawString         (0, 1*24, "    HID Class       ");
  GLCD_DrawString         (0, 2*24, "    HID Example     ");
  GLCD_DrawString         (0, 4*24, "  USB: HID0         ");
  GLCD_DrawString         (0, 8*24, "  Keil Tools by ARM ");
  GLCD_DrawString         (0, 9*24, "    www.keil.com    ");

  USBD_Initialize         (0);          /* USB Device 0 Initialization        */
  USBD_Connect            (0);          /* USB Device 0 Connect               */

  while (1) {
    // Wait until USB Device is configured
    while (!USBD_Configured (0)) { osDelay(100); }

    buf = 0;
    while (1) {                         /* Send HID report to Host on change  */
      if (USBD_Configured (0)) {
        joy = (uint8_t)(Joystick_GetState ());
        if (joy ^ buf) {
          buf = joy;
          USBD_HID_GetReportTrigger(0, 0, &buf, 1);
        }
      } else {
        break;
      }
      osDelay(100);                     /* 100 ms delay for sampling joystick */
    }
  }
}
