/* -----------------------------------------------------------------------------
 * Copyright (c) 2013-2014 ARM Ltd.
 *
 * This software is provided 'as-is', without any express or implied warranty.
 * In no event will the authors be held liable for any damages arising from
 * the use of this software. Permission is granted to anyone to use this
 * software for any purpose, including commercial applications, and to alter
 * it and redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software in
 *    a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source distribution.
 *
 *
 * $Date:        26. August 2016
 * $Revision:    V1.1
 *
 * Project:      PIN Driver for NXP LPC177x_8x
 * -------------------------------------------------------------------------- */

#include "LPC177x_8x.h"
#include "PIN_LPC177x_8x.h"

#define PIN_Cfg(port,pin)     (*((volatile uint32_t *) (LPC_IOCON_BASE + ((port * 32 + pin)*sizeof(uint32_t)))))

/**
  \fn          int32_t PIN_Configure (uint32_t function) {
  \brief       Set pin function and electrical characteristics
  \param[in]   port       port number (0..3)
  \param[in]   pin        pin number  (0..31)
  \param[in]   pin_cfg    pin_cfg configuration bit mask
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t PIN_Configure (uint8_t port, uint8_t pin, uint32_t pin_cfg) {

  if ((port > 5) || (pin > 31)) return -1;
  PIN_Cfg(port, pin) = pin_cfg;
  return(0);  
}

/**
  \fn          PIN_ConfigureI2C0Pins (uint8_t port, uint8_t pin, uint32_t i2cMode)
  \brief       Configure I2C pins
  \param[in]   port       port number (0..3)
  \param[in]   pin        pin number  (0..31)
  \param[in]   i2cMode    I2C mode
                - PIN_I2CMODE_FAST_STANDARD
                - PIN_I2CMODE_OPENDRAINIO
                - PIN_I2CMODE_FASTMODEPLUS
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t PIN_ConfigureI2C0Pins (uint8_t port, uint8_t pin, uint32_t i2cMode)
{

  switch(port)
  {
    case 0:
      if ((pin == 27) || (pin == 28)) break;
      else return (-1);
    case 5:
      if ((pin == 2 ) || (pin ==  3)) break;
      else return (-1);
    default:
      return (-1);
  }

  switch(i2cMode)
  {
    case PIN_I2CMODE_FAST_STANDARD:
      PIN_Cfg(port, pin) &= ~(IOCON_I2C_FILTER_DISABLE);
      PIN_Cfg(port, pin) &= ~(IOCON_I2CMODE_FASTPLUS);
      break;
    case PIN_I2CMODE_OPENDRAINIO:
      PIN_Cfg(port, pin) |=  (IOCON_I2C_FILTER_DISABLE);
      PIN_Cfg(port, pin) &= ~(IOCON_I2CMODE_FASTPLUS);
      break;
    case PIN_I2CMODE_FASTMODEPLUS:
      PIN_Cfg(port, pin) &= ~(IOCON_I2C_FILTER_DISABLE);
      PIN_Cfg(port, pin) |=  (IOCON_I2CMODE_FASTPLUS);
      break;
    default:
      return (-1);
  }

  return(0);
}
