/* -----------------------------------------------------------------------------
 * Copyright (c) 2013-2015 ARM Ltd.
 *
 * This software is provided 'as-is', without any express or implied warranty.
 * In no event will the authors be held liable for any damages arising from
 * the use of this software. Permission is granted to anyone to use this
 * software for any purpose, including commercial applications, and to alter
 * it and redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software in
 *    a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source distribution.
 *
 *
 * $Date:        27. October 2015
 * $Revision:    V2.0
 *
 * Project:      SPI Driver Definitions for NXP LPC17xx
 * -------------------------------------------------------------------------- */

#ifndef __SPI_LPC17XX_H
#define __SPI_LPC17XX_H

#if defined (LPC175x_6x)
  #include "LPC17xx.h"
  #include "PIN_LPC17xx.h"
#else
#error "SPI peripheral not available for selected Device."
#endif

#include "Driver_SPI.h"

/* SPI Register Interface Definitions */
#define CGU_BASE_SPI_CLK_PD               (0x01U << 0)      /*!< CGU BASE_SPI_CLK: PD Mask               */
#define CGU_BASE_SPI_CLK_AUTOBLOCK        (0x01U << 11)     /*!< CGU BASE_SPI_CLK: AUTOBLOCK Mask        */
#define CGU_BASE_SPI_CLK_CLK_SEL          (0x1FU << 24)     /*!< CGU BASE_SPI_CLK: CLK_SEL Mask          */
#define CCU1_CLK_SPI_CFG_RUN              (0x01U << 0)      /*!< CCU1 CLK SPI CFG: RUN Mask              */
#define CCU1_CLK_SPI_CFG_AUTO             (0x01U << 1)      /*!< CCU1 CLK SPI CFG: AUTO Mask             */
#define CCU1_CLK_SPI_CFG_WAKEUP           (0x01U << 2)      /*!< CCU1 CLK SPI CFG: WAKEUP Mask           */
#define CCU1_CLK_SPI_STAT_RUN             (0x01U << 0)      /*!< CCU1 CLK SPI STAT: RUN Mask             */
#define CCU1_CLK_SPI_STAT_AUTO            (0x01U << 1)      /*!< CCU1 CLK SPI STAT: AUTO Mask            */
#define CCU1_CLK_SPI_STAT_WAKEUP          (0x01U << 2)      /*!< CCU1 CLK SPI STAT: WAKEUP Mask          */
#define RGU_RESET_CTRL1_SPI_RST           (0x01U << 26)     /*!< RGU RESET_CTRL1: SPI_RST Mask           */
#define RGU_RESET_STATUS3_SPI_RST         (0x03U << 20)     /*!< RGU RESET_STATUS3: SPI_RST Mask         */
#define RGU_RESET_ACTIVE_STATUS1_SPI_RST  (0x01U << 26)     /*!< RGU RESET_ACTIVE_STATUS1: SPI_RST Mask  */

#define SPI_CR_BITENABLE                  (0x01U << 2)      /*!< SPI CR: BITENABLE Mask                  */
#define SPI_CR_CPHA                       (0x01U << 3)      /*!< SPI CR: CPHA Mask                       */
#define SPI_CR_CPOL                       (0x01U << 4)      /*!< SPI CR: CPOL Mask                       */
#define SPI_CR_MSTR                       (0x01U << 5)      /*!< SPI CR: MSTR Mask                       */
#define SPI_CR_LSBF                       (0x01U << 6)      /*!< SPI CR: LSBF Mask                       */
#define SPI_CR_SPIE                       (0x01U << 7)      /*!< SPI CR: SPIE Mask                       */
#define SPI_CR_BITS                       (0x0fU << 8)      /*!< SPI CR: BITS Mask                       */
#define SPI_SR_ABRT                       (0x01U << 3)      /*!< SPI SR: ABRT Mask                       */
#define SPI_SR_MODF                       (0x01U << 4)      /*!< SPI SR: MODF Mask                       */
#define SPI_SR_ROVR                       (0x01U << 5)      /*!< SPI SR: ROVR Mask                       */
#define SPI_SR_WCOL                       (0x01U << 6)      /*!< SPI SR: WCOL Mask                       */
#define SPI_SR_SPIF                       (0x01U << 7)      /*!< SPI SR: SPIF Mask                       */
#define SPI_DR_DATALOW                    (0xFFU << 0)      /*!< SPI DR: DATALOW Mask                    */
#define SPI_DR_DATAHIGH                   (0xFFU << 8)      /*!< SPI DR: DATAHIGH Mask                   */
#define SPI_CCR_COUNTER                   (0xFFU << 0)      /*!< SPI CCR: COUNTER Mask                   */
#define SPI_TCR_TEST                      (0x7FU << 1)      /*!< SPI TCR: TEST Mask                      */
#define SPI_TSR_ABRT                      (0x01U << 3)      /*!< SPI TSR: ABRT Mask                      */
#define SPI_TSR_MODF                      (0x01U << 4)      /*!< SPI TSR: MODF Mask                      */
#define SPI_TSR_ROVR                      (0x01U << 5)      /*!< SPI TSR: ROVR Mask                      */
#define SPI_TSR_WCOL                      (0x01U << 6)      /*!< SPI TSR: WCOL Mask                      */
#define SPI_TSR_SPIF                      (0x01U << 7)      /*!< SPI TSR: SPIF Mask                      */
#define SPI_INT_SPIF                      (0x01U << 0)      /*!< SPI INT: SPIF Mask                      */

// Peripheral clock divider definitions
#define PCLKSEL_CCLK_DIV_1   (1U)
#define PCLKSEL_CCLK_DIV_2   (2U)
#define PCLKSEL_CCLK_DIV_4   (0U)
#define PCLKSEL_CCLK_DIV_8   (3U)

// SSP peripheral clock selection bit position definitions
#define SPI_PCLKSEL0_POS     (16U)

/* Current driver status flag definition */
#define SPI_INITIALIZED                   (1U    << 0)      // SPI initialized
#define SPI_POWERED                       (1U    << 1)      // SPI powered on
#define SPI_CONFIGURED                    (1U    << 2)      // SPI configured
#define SPI_DATA_LOST                     (1U    << 3)      // SPI data lost occurred
#define SPI_MODE_FAULT                    (1U    << 4)      // SPI mode fault occurred

/* SPI Pins Configuration */
typedef const struct _SPI_PINS {
  PIN                  *ssel;           // SSEL pin
  PIN                  *sck;            // SCK pin
  PIN                  *miso;           // MISO pin
  PIN                  *mosi;           // MOSI pin
  uint8_t               ssel_func;      // SSEL pin alternate function
  uint8_t               sck_func;       // SCK pin alternate function
  uint8_t               miso_func;      // MISO pin alternate function
  uint8_t               mosi_func;      // MOSI pin alternate function
} SPI_PINS;

/* Clocks Configuration */
typedef const struct _SPI_CLOCK {
  uint32_t              reg_pwr_val;    // SPI block power control register value
  volatile uint32_t    *reg_pwr;        // SPI block power control  register
  uint32_t              peri_cfg_pos;   // SPI peripheral clock configuration position
  uint32_t              peri_cfg_val;   // SPI peripheral clock configuration value
  volatile uint32_t    *peri_cfg;       // SPI peripheral clock configuration register
} SPI_CLOCKS;

/* SPI status */
typedef struct _SPI_STATUS {
  uint8_t busy;                         // Transmitter/Receiver busy flag
  uint8_t data_lost;                    // Data lost: Receive overflow / Transmit underflow (cleared on start of transfer operation)
  uint8_t mode_fault;                   // Mode fault detected; optional (cleared on start of transfer operation)
} SPI_STATUS;

/* SPI Information (Run-time) */
typedef struct _SPI_INFO {
  ARM_SPI_SignalEvent_t cb_event;       // Event Callback
  SPI_STATUS            status;         // Status flags
  uint8_t               state;          // Current SPI state
  uint32_t              mode;           // Current SPI mode
} SPI_INFO;

/* SPI Transfer Information (Run-Time) */
typedef struct _SPI_TRANSFER_INFO {
  uint32_t              num;            // Total number of transfers
  uint8_t              *rx_buf;         // Pointer to in data buffer
  uint8_t              *tx_buf;         // Pointer to out data buffer
  uint32_t              rx_cnt;         // Number of data received
  uint32_t              tx_cnt;         // Number of data sent
  uint32_t              dump_val;       // Variable for dumping DMA data
  uint16_t              def_val;        // Default transfer value
} SPI_TRANSFER_INFO;

/* SPI Resources */
typedef struct {
  LPC_SPI_TypeDef      *reg;            // SPI peripheral register interface
  SPI_PINS              pin;            // SPI pins configuration
  SPI_CLOCKS            clk;            // SPI clocks configuration
  IRQn_Type             irq_num;        // SPI IRQ number
  SPI_INFO             *info;           // SPI Run-time information
  SPI_TRANSFER_INFO    *xfer;           // SPI transfer information
} const SPI_RESOURCES;

#endif /* __SPI_LPC17XX_H */
